#!/usr/bin/env bash

kubectl apply -f - <<EOF
apiVersion: v1
kind: LimitRange
metadata:
  name: cpu-memory-limits
spec:
  limits:
  - type: Container
    default:
      memory: 500m
      cpu: 500m
    defaultRequest:
      memory: 500m
      cpu: 500m
EOF

kubectl apply -f - <<EOF
apiVersion: apps/v1
kind: Deployment
metadata:
  name: test-app
spec:
  selector:
    matchLabels:
      app: test-app
  template:
    metadata:
      labels:
        app: test-app
    spec:
      containers:
      - name: test-app
        image: nginx:latest
        ports:
        - containerPort: 8080
EOF

kubectl apply -f - <<EOF
apiVersion: keda.sh/v1alpha1
kind: ScaledObject
metadata:
  name: test-scaled-object
spec:
  scaleTargetRef:
    apiVersion: apps/v1
    kind: Deployment
    name: test-app
    envSourceContainerName: test-app
  pollingInterval: 2
  cooldownPeriod: 300
  idleReplicaCount: 0
  minReplicaCount: 1
  maxReplicaCount: 100
  fallback:
    failureThreshold: 3
    replicas: 6
  advanced:
    restoreToOriginalReplicaCount: true
  triggers:
  - type: cpu
    metricType: Utilization
    metadata:
      type: Utilization
      value: "60"
      containerName: ""
  - type: memory
    metricType: Utilization
    metadata:
      type: Utilization
      value: "60"
      containerName: ""
EOF

kubectl delete deploy/test-app
kubectl delete scaledobject/test-scaled-object
kubectl delete limitrange/cpu-memory-limits
